Fuzzy Commands
==============

[![Generated by attribution][attribution-badge]][attribution-url]


v0.1
----

Initial release

- New `FuzzyCommandGroup` class with automatic prefix and fuzzy matching

```text
$ git shortlog -s v0.1
     9	Amethyst Reese
```

[attribution-badge]:
    https://img.shields.io/badge/generated%20by-attribution-informational
[attribution-url]: https://attribution.omnilib.dev
